<template>
	<div class="h100 overflow-y-auto p-[16px]">
		<div class="mb-[10px] flex items-center">
			<el-button style="margin-left: 8px; width: 40px" text @click="handleExitFlow">
				<el-icon style="font-size: 24px !important">
					<ArrowLeft />
				</el-icon>
			</el-button>
			<span class="text-[24px] text-[#26244c] font-[700]">{{ state.detailTitle }}</span>
		</div>
		<div class="relative">
			<div class="relative transition-[opacity 0.3s]">
				<div class="set-form-height">
					<div class="flex flex-col">
						<el-divider content-position="left"><span class="text-[18px]">知识库基础信息</span></el-divider>
						<el-form :model="state.categoryForm" label-width="120px" label-position="left">
							<el-form-item label="知识库名称:">
								<el-input
									v-model="state.categoryForm.ImportCategory"
									style="width: 532px"
									maxlength="20"
									placeholder="请输入知识库名称"
									show-word-limit
									type="text"
								/>
							</el-form-item>
							<el-form-item label="知识库描述:">
								<el-input
									v-model="state.categoryForm.CategoryType"
									maxlength="1000"
									style="width: 532px"
									placeholder="请输入知识库描述。对知识库包含的内容和数据的用途进行描述。"
									show-word-limit
									:rows="5"
									type="textarea"
								/>
							</el-form-item>
							<el-form-item label="数据类型:">
								<div v-for="(item, index) in state.dataTypeList" :key="index">
									<div
										class="bg-[#f6f5ff] border-[1px] border-solid border-[#0062be] py-[12px] w-[215px] px-[16px] rounded-lg cursor-pointer"
									>
										<el-radio v-model="state.categoryForm.dataType" size="large">
											<span class="font-[700] text[14px]">{{ item.Name }}</span>
										</el-radio>

										<el-tooltip :content="item.DemoDesc" placement="top" effect="light" popper-class="set_tooltip_demo">
											<div class="text-[#878aab] text-[12px] mx-0 mt-[2px] mb-0 set-desc">
												{{ item.DemoDesc }}
											</div>
										</el-tooltip>
									</div>
								</div>
							</el-form-item>
							<!-- <el-form-item label="配置模式:">
								<div
									class="bg-[#f6f5ff] border-[1px] border-solid border-[#0062be] py-[12px] w-[215px] px-[16px] rounded-lg cursor-pointer"
								>
									<el-radio-group v-model="state.categoryForm.configurationMode">
										<el-radio value="1" size="large">
											<span class="font-[700] text[14px]">文档智能解析</span>
										</el-radio>
									</el-radio-group>
									<el-tooltip :content="state.demoDesc" placement="top" effect="light" popper-class="set_tooltip_demo">
										<div class="text-[#878aab] text-[12px] mx-0 mt-[2px] mb-0 set-desc">
											{{ state.demoDesc }}
										</div>
									</el-tooltip>
								</div>
							</el-form-item> -->
						</el-form>

						<div class="set-form-footer">
							<el-button type="primary" @click="onSubmit">下一步</el-button>
							<el-button>取消</el-button>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
</template>

<script setup lang="ts">
import type { UploadUserFile } from 'element-plus';
import { reactive, ref } from 'vue';
import { useRouter } from 'vue-router';
// 定义变量内容
const state = reactive({
	detailTitle: '创建知识库',
	categoryForm: {
		ImportCategory: '',
		CategoryType: '本地类目',
		dataType: '1',
		configurationMode: '1',
	},
	dataTypeList: [
		{
			ID: 1,
			Name: '非结构化数据',
			ImageURL: 'static/images/knowledge/data_type_1.png',
			DemoDesc: '选择数据管理功能中已上传的doc、pdf、md、txt等文件',
		},
		{
			ID: 2,
			Name: '结构化数据',
			ImageURL: 'static/images/knowledge/data_type_2.png',
			DemoDesc: '选择数据管理功能中已创建的数据表',
		},
	],
});
const fileList = ref<UploadUserFile[]>([]);
const router = useRouter();
//返回
const handleExitFlow = () => {
	//是否显示返回
	router.back();
};
//确认
const onSubmit = () => {};
</script>
<style scoped lang="scss">
.set-form-height {
	height: calc(100% - 62px);
	background: #fff;
	border-radius: 16px 16px 0 0;
	flex: 1;
	margin: 0 24px 64px;
	overflow-y: auto;
	padding: 20px;
}
.set-desc {
	-webkit-line-clamp: 2;
	display: -webkit-box;
	-webkit-box-orient: vertical;
	overflow: hidden;
	word-break: break-word;
	line-height: 1.5714285714285714;
	font-family: PingFangSC;
	box-sizing: border-box;
}
.set-form-footer {
	align-items: center;
	background: #fff;
	bottom: 0;
	box-shadow: 4px 0 5px 1px rgba(16, 9, 65, 0.06);
	display: flex;
	flex-shrink: 0;
	gap: 8px;
	height: 64px;
	padding-left: 24px;
	position: fixed;
	width: 100%;
	left: 220px;
}
</style>
<style>
.set_tooltip_demo {
	max-width: 326px;
	max-height: 150px;
	min-width: 32px;
	min-height: 32px;
	padding: 6px 8px;
	color: #26244c;
	text-align: start;
	text-decoration: none;
	word-wrap: break-word;
	background-color: #fff;
	border-radius: 6px;
	box-shadow: 0 6px 16px 0 rgba(0, 0, 0, 0.08), 0 3px 6px -4px rgba(0, 0, 0, 0.12), 0 9px 28px 8px rgba(0, 0, 0, 0.05);
	box-sizing: border-box;
}
</style>
